@@ -1,13 +1,17 @@
 from dataclasses import dataclass, field
-from typing import Callable, Generic, TypeVar, runtime_checkable
+from typing import Callable, Generic, TypeVar
 import toolz
-from typing_extensions import Protocol
+import sys
+
+if sys.version_info >= (3, 8):
+    from typing import Protocol
+else:
+    from typing_extensions import Protocol
 
 
 T = TypeVar("T")
 
 
-@runtime_checkable
 class Monoid(Protocol):
     def __add__(self, other: "Monoid") -> "Monoid":
         ...
